pub trait TimerHandle: Send + 'static {
// Required method
fn cancel(self);
}Expand description
A handle to a scheduled timer that can be cancelled.
pub trait TimerHandle: Send + 'static {
// Required method
fn cancel(self);
}A handle to a scheduled timer that can be cancelled.